@@ -88,6 +88,11 @@ class TestJsonpath_rw_ext(testscenarios.WithScenarios,
                                               {'cow': 'neigh'},
                                               {'cat': 'neigh'}]},
                             target=[{'cow': 'moo'}])),
+        ('filter_eq4', dict(string='objects[?id==154]',
+                            data={'objects': [{'id': 154},
+                                              {'id': 155},
+                                              {'id': None}]},
+                            target=[{'id': 154}])),
         ('filter_gt', dict(string='objects[?cow>5]',
                            data={'objects': [{'cow': 8},
                                              {'cow': 7},
